==> verticalpodautoscaler-model-v1-6.5.1-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/RecommendedPodResourcesFluent.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface RecommendedPodResourcesFluent<A extends RecommendedPodResourcesFluent<A>> extends Fluent<A>{
  public A addToContainerRecommendations(Integer index,RecommendedContainerResources item);
  public A setToContainerRecommendations(Integer index,RecommendedContainerResources item);
  public A addToContainerRecommendations(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources... items);
  public A addAllToContainerRecommendations(Collection<RecommendedContainerResources> items);
  public A removeFromContainerRecommendations(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources... items);
  public A removeAllFromContainerRecommendations(Collection<RecommendedContainerResources> items);
  public A removeMatchingFromContainerRecommendations(Predicate<RecommendedContainerResourcesBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildContainerRecommendations instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RecommendedContainerResources> getContainerRecommendations();
  public List<RecommendedContainerResources> buildContainerRecommendations();
  public RecommendedContainerResources buildContainerRecommendation(Integer index);
  public RecommendedContainerResources buildFirstContainerRecommendation();
  public RecommendedContainerResources buildLastContainerRecommendation();
  public RecommendedContainerResources buildMatchingContainerRecommendation(Predicate<RecommendedContainerResourcesBuilder> predicate);
  public Boolean hasMatchingContainerRecommendation(Predicate<RecommendedContainerResourcesBuilder> predicate);
  public A withContainerRecommendations(List<RecommendedContainerResources> containerRecommendations);
  public A withContainerRecommendations(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources... containerRecommendations);
  public Boolean hasContainerRecommendations();
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> addNewContainerRecommendation();
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> addNewContainerRecommendationLike(RecommendedContainerResources item);
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> setNewContainerRecommendationLike(Integer index,RecommendedContainerResources item);
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editContainerRecommendation(Integer index);
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editFirstContainerRecommendation();
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editLastContainerRecommendation();
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editMatchingContainerRecommendation(Predicate<RecommendedContainerResourcesBuilder> predicate);
  public interface ContainerRecommendationsNested<N> extends Nested<N>,RecommendedContainerResourcesFluent<RecommendedPodResourcesFluent.ContainerRecommendationsNested<N>>{
    public N and();
    public N endContainerRecommendation();
    
  }
  
}

==> verticalpodautoscaler-model-v1-6.7.2-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/RecommendedPodResourcesFluent.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface RecommendedPodResourcesFluent<A extends RecommendedPodResourcesFluent<A>> extends Fluent<A>{
  public A addToContainerRecommendations(int index,RecommendedContainerResources item);
  public A setToContainerRecommendations(int index,RecommendedContainerResources item);
  public A addToContainerRecommendations(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources... items);
  public A addAllToContainerRecommendations(Collection<RecommendedContainerResources> items);
  public A removeFromContainerRecommendations(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources... items);
  public A removeAllFromContainerRecommendations(Collection<RecommendedContainerResources> items);
  public A removeMatchingFromContainerRecommendations(Predicate<RecommendedContainerResourcesBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildContainerRecommendations instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RecommendedContainerResources> getContainerRecommendations();
  public List<RecommendedContainerResources> buildContainerRecommendations();
  public RecommendedContainerResources buildContainerRecommendation(int index);
  public RecommendedContainerResources buildFirstContainerRecommendation();
  public RecommendedContainerResources buildLastContainerRecommendation();
  public RecommendedContainerResources buildMatchingContainerRecommendation(Predicate<RecommendedContainerResourcesBuilder> predicate);
  public Boolean hasMatchingContainerRecommendation(Predicate<RecommendedContainerResourcesBuilder> predicate);
  public A withContainerRecommendations(List<RecommendedContainerResources> containerRecommendations);
  public A withContainerRecommendations(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources... containerRecommendations);
  public Boolean hasContainerRecommendations();
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> addNewContainerRecommendation();
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> addNewContainerRecommendationLike(RecommendedContainerResources item);
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> setNewContainerRecommendationLike(int index,RecommendedContainerResources item);
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editContainerRecommendation(int index);
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editFirstContainerRecommendation();
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editLastContainerRecommendation();
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editMatchingContainerRecommendation(Predicate<RecommendedContainerResourcesBuilder> predicate);
  public interface ContainerRecommendationsNested<N> extends Nested<N>,RecommendedContainerResourcesFluent<RecommendedPodResourcesFluent.ContainerRecommendationsNested<N>>{
    public N and();
    public N endContainerRecommendation();
    
  }
  
}
